@@ -151,7 +151,7 @@ C<XDEBUG_SESSION> cookie.
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
     DEBUG_SINGLE_STEP_ON        =>  0x20,
@@ -208,13 +208,13 @@ sub import {
     if (!$args{remote_host}) {
         my $error;
         my ($user, $dbgp_client_dir) = @args{qw(user client_dir)};
-        my $group = getgrnam($));
+        my $group = getgrnam($)) || (split / /, $))[0];
 
         if (!$user || !$dbgp_client_dir) {
             # pass through and hope for the best
         } elsif (-d $dbgp_client_dir) {
             my ($mode, $uid, $gid) = (stat($dbgp_client_dir))[2, 4, 5];
-            my $user_id = getpwnam($user) // die "Can't retrieve the UID for $user";
+            my $user_id = getpwnam($user) || die "Can't retrieve the UID for $user";
 
             $error = sprintf "invalid UID %d, should be %d", $uid, $user_id
                 unless $uid == $user_id;
